@@ -2,6 +2,7 @@ import logging
 import sys
 import os
 import csv
+import random
 
 from collections import defaultdict
 from pathlib import Path
@@ -33,6 +34,7 @@ def annotate_junctions(
     consider_unannotated_references_novel,
     junction_dir,
     disable_junction_files,
+    sample_rate=1,
 ):
     try:
         ngsfile = NGSFile(ngsfilepath)
@@ -48,7 +50,7 @@ def annotate_junctions(
             "complete_novel_spliced_reads": "N/A",
             "partial_novel_spliced_reads": "N/A",
         }
-        return [result]
+        return result
 
     if ngsfile.filetype != NGSFileType.BAM:
         raise RuntimeError(
@@ -97,6 +99,11 @@ def annotate_junctions(
             f"Found {len(events)} potential splice junctions. {len(found_introns) - len(events)} potential junctions too short."
         )
 
+        if sample_rate < 1:
+            n_samples = round(len(events) * sample_rate)
+            events = random.sample(events, n_samples)
+            logger.debug(f"Randomly sampled {n_samples} events.")
+
         if contig not in cache.exon_starts:
             logger.info(f"{contig} not found in GFF. All events marked `unannotated_reference`.")
             annotation = "unannotated_reference"
